# finmc

[![CI](https://github.com/somdipdatta/finmc/actions/workflows/main.yml/badge.svg)](https://github.com/somdipdatta/finmc/actions/workflows/main.yml)

This package contains Monte-Carlo implementations of many financial models derived from a common interface class. This interface allows computation of instruments with european, and american payoffs, as well as path dependent calculations.

More details coming soon.

<table>
<tr>
<td> <img src="images/impliedvol.png" alt="implied vol"/> </td>
<td> <img src="images/rate_mc.png" alt="rate mc"/> </td>
</tr>
</table>

## Install it from PyPI

```bash
pip install finmc
```
